=========================
Template tags and filters
=========================


.. note::

 In each of the following examples it is understood that you have already loaded the ``django_wikiwikiweb``
 template tag library, placing the code below at the beginning of each template in which the ``django_wikiwikiweb``
 template tag library will be used. Read the :doc:`installation` section[s] to understand how
 to accomplish this.


linkify
~~~~~~~

.. autofunction:: wikiwikiweb.templatetags.wiki_extras.linkify

make_title
~~~~~~~~~~

.. autofunction:: wikiwikiweb.templatetags.wiki_extras.make_title